@@ -369,8 +369,30 @@ KDE_NO_EXPORT void MediaInfo::ready () {
         node->document()->post (node, new Posting (node, MsgMediaReady));
 }
 
+static bool validDataFormat (ActorAgent::ActorType type, const ByteArray &ba) {
+    switch (type) {
+    case ActorAgent::Any:
+        //TODO
+    case ActorAgent::Audio:
+    case ActorAgent::AudioVideo: {
+        bool kill (ba.size () > 2000000 ||            // too big
+                (ba.size () > 4 &&
+                 !strncmp (ba.data (), "RIFF", 4))); // falsely seen as text
+        if (!kill && ba.size() > 14) {
+            String ct = MimeType::findByContent (ba.data(), ba.size ());
+            kill = !ct.startsWith ("text/") ||
+                (!strncasecmp (ba.data (), "<html", 5) || // html admin
+                 !strncasecmp (ba.data (), "<!doctype html", 14));
+        }
+        return !kill;
+    }
+    default:
+        return true;
+    }
+}
+
 KDE_NO_EXPORT void MediaInfo::jobResult (IOJob *jb) {
-    if (jb->error ())
+    if (jb->error () || (data.size () < 512 && !validDataFormat (type, data)))
         data.resize (0);
     job = 0L; // signal KIO::IOJob::result deletes itself
     if (ActorAgent::Data != type && mime.isEmpty ()) {
@@ -388,26 +410,14 @@ KDE_NO_EXPORT void MediaInfo::jobData (IOJob *jb, ByteArray &ba) {
     if (ba.size ()) {
         int old_size = data.size ();
         int newsize = old_size + ba.size ();
-        switch (type) {
-            case ActorAgent::Any:
-                //TODO
-            case ActorAgent::Audio:
-            case ActorAgent::AudioVideo:
-                if (newsize > 2000000 ||
-                        (!old_size &&
-                         (!MimeType::findByContent (ba.data (), ba.size ()).startsWith ("text/") ||
-                          (newsize > 4 && !strncmp (ba.data (), "RIFF", 4))))) {
-                    data.resize (0);
-                    job->kill (false); // not quiet, wants jobResult
-                    return;
-                }
-                break;
-            default:
-                //TODO
-                break;
-        }
+
         data.resize (newsize);
         memcpy (data.data () + old_size, ba.data (), ba.size ());
+
+        if (old_size < 512 && newsize >= 512 && !validDataFormat (type, data)) {
+            data.resize (0);
+            job->kill (false); // not quiet, wants jobResult
+        }
     }
 }
 
