@@ -46,26 +46,34 @@ gint dbus_req_handler (const gchar *interface, const gchar *method,
         GArray *arguments, gpointer data, osso_rpc_t *retval);
 void exit_event_handler (gboolean die_now, gpointer data);
 
-gchar *app_file_chooser (Application *app, const char *title, GtkFileChooserAction act) {
+gchar *app_file_chooser (Application *app, const char *def, GtkFileChooserAction act) {
     GtkWidget *dialog;
     gchar *filename = NULL;
-    dialog = hildon_file_chooser_dialog_new (app->window, act);
-    if (app->save_folder)
-        gtk_file_chooser_set_current_folder (
-                GTK_FILE_CHOOSER (dialog), app->save_folder);
-    if (title)
-        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), title);
-    gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
-    gtk_widget_show_all (GTK_WIDGET (dialog));
-    if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-        filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-        if (filename && filename[0]) {
-            if (app->save_folder)
-                g_free (app->save_folder);
-            app->save_folder = dirname (g_strdup (filename));
+    char *dir = NULL, *file = NULL;
+    gchar *path = def && def[0] ? g_strdup (def) : NULL;
+    if (path && path[0]) {
+        if (path [strlen (path) -1] != '/' &&
+                strcmp (path, "/home/user/MyDocs") &&
+                strcmp (path, "/media/mmc1") &&
+                strcmp (path, "/media/mmc2")) {
+            file = basename (path);
+            dir = dirname (path);
+        } else {
+            dir = path;
         }
     }
+    dialog = hildon_file_chooser_dialog_new (app->window, act);
+    if (dir)
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), dir);
+    if (file && file[0])
+        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), file);
+    /*gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);*/
+    gtk_widget_show_all (GTK_WIDGET (dialog));
+    if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+        filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
     gtk_widget_destroy (dialog);
+    if (path)
+        g_free (path);
     return filename;
 }
 
@@ -193,12 +201,23 @@ void app_normal_screen (Application *app) {
     }
 }
 
+void app_store_save_directory (Application *app, gchar *path) {
+    if (path && path[0]) {
+        if (app->save_folder)
+            g_free (app->save_folder);
+        char *dir = dirname (path);
+        app->save_folder = (gchar *) g_malloc (strlen (dir) + 2);
+        sprintf (app->save_folder, "%s/", dir);
+        g_free (dir);
+    }
+}
+
 static void callback_file_open (GtkButton * button, Application * app) {
     gchar *filename = NULL;
-    filename = app_file_chooser(app, NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
+    filename = app_file_chooser(app, app->save_folder, GTK_FILE_CHOOSER_ACTION_OPEN);
     if (filename) {
         app_open_location (filename, app);
-        g_free (filename);
+        app_store_save_directory (app, filename);
     }
 }
 
@@ -215,7 +234,7 @@ static void callback_file_go (GtkButton *button, Application *app) {
 
 static void callback_file_save_as (GtkButton * button, Application * app) {
     gchar *filename = NULL;
-    filename = app_file_chooser (app, NULL, GTK_FILE_CHOOSER_ACTION_SAVE);
+    filename = app_file_chooser (app, app->save_folder, GTK_FILE_CHOOSER_ACTION_SAVE);
     if (filename) {
         gchar * info;
         if (saveFile (app->control, filename)) {
@@ -226,7 +245,7 @@ static void callback_file_save_as (GtkButton * button, Application * app) {
             info = g_strdup_printf ("Saving as %s failed (%s)", filename, strerror (errno));
         hildon_banner_show_information (GTK_WIDGET (app->window), NULL, info);
         g_free (info);
-        g_free (filename);
+        app_store_save_directory (app, filename);
     }
 }
 
@@ -403,10 +422,12 @@ static void create_menu (Application * app) {
     GtkWidget *item_save;
     GtkWidget *item_save_as;
     GtkWidget *menu_playlist;
+    GtkWidget *menu_generators;
     GtkWidget *menu_players;
     GtkWidget *item_close;
     GtkWidget *item_playlist;
     GtkWidget *item_playlist_show;
+    GtkWidget *item_playlist_generators;
     GtkWidget *item_players;
 
     /* Get the menu from view */
@@ -414,6 +435,7 @@ static void create_menu (Application * app) {
 
     /* Create new submenu for "Others" */
     menu_playlist = gtk_menu_new ();
+    menu_generators = gtk_menu_new ();
     menu_players = gtk_menu_new ();
 
     /* Create menu items */
@@ -424,6 +446,7 @@ static void create_menu (Application * app) {
     /* item_check = gtk_check_menu_item_new_with_label ("Check");*/
     item_playlist = gtk_menu_item_new_with_label ("Playlist");
     item_playlist_show = gtk_check_menu_item_new_with_label ("Show");
+    item_playlist_generators = gtk_menu_item_new_with_label("Generators");
     app->menu_item_playlist_copy = gtk_menu_item_new_with_label("Copy");
     app->menu_item_playlist_paste = gtk_menu_item_new_with_label("Paste");
     app->menu_item_playlist_paste_in_group = gtk_menu_item_new_with_label ("Paste in new Group");
@@ -453,6 +476,8 @@ static void create_menu (Application * app) {
     gtk_menu_append (menu_playlist, app->menu_item_playlist_paste_in_group);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_cut);
     gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
+    gtk_menu_append (menu_playlist, item_playlist_generators);
+    gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
     gtk_menu_append (menu_playlist, app->menu_item_playlist_title);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_showall);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_edit);
@@ -465,6 +490,7 @@ static void create_menu (Application * app) {
 
     /* Add others submenu to the "Others" item */
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_playlist), menu_playlist);
+    gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_playlist_generators), menu_generators);
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_players), menu_players);
 
     /* Attach the callback functions to the activate signal */
@@ -488,6 +514,8 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (cb_playlistPasteInNewGroup), app);
     g_signal_connect (G_OBJECT (app->menu_item_playlist_cut), "activate",
         GTK_SIGNAL_FUNC (cb_playlistCut), app);
+    g_signal_connect (G_OBJECT (item_playlist_generators), "activate",
+        GTK_SIGNAL_FUNC (generatorMenuActivate), app);
     g_signal_connect (G_OBJECT (app->menu_item_playlist_title), "activate",
         GTK_SIGNAL_FUNC (cb_playlistTitle), app);
     g_signal_connect (G_OBJECT (item_playlist_show), "toggled",
