@@ -26,6 +26,7 @@
 #define MAEMO_NO_EXPORT __attribute__ ((visibility("hidden")))
 
 #define GCONF_KEY_PREFIX "/apps/maemo/kmplayer"
+#define GCONF_KEY_DATA_DIR GCONF_KEY_PREFIX"/data_dir"
 #define GCONF_KEY_RECENT_FILE GCONF_KEY_PREFIX"/recent_file"
 #define GCONF_KEY_PLAYLIST_FILE GCONF_KEY_PREFIX"/playlist_file"
 #define GCONF_KEY_LOCATION_URL GCONF_KEY_PREFIX"/location"
@@ -34,6 +35,7 @@
 #define GCONF_KEY_SAVE_FOLDER GCONF_KEY_PREFIX"/save_folder"
 #define GCONF_KEY_MIME GCONF_KEY_PREFIX"/mimetypes/"
 #define GCONF_KEY_LISTS GCONF_KEY_PREFIX"/lists"
+#define GCONF_KEY_KEYS GCONF_KEY_PREFIX"/keys/"
 
 #define HSPLIT 320
 #define VSPLIT 260
@@ -117,6 +119,7 @@ void cb_view_area_expose (GtkWidget *widget, GdkEventExpose *event, Application
 void cb_view_area_configure (GtkWidget *widget, GdkEventConfigure *event, Application * app);
 void cb_view_area_button_press (GtkWidget *widget, GdkEventButton *event, Application * app);
 void cb_playlistMenuActivate (GtkButton * button, Application * app);
+void generatorMenuActivate (GtkMenuItem *item, Application * app);
 void cb_playlistCopy (GtkButton * button, Application * app);
 void cb_playlistPaste (GtkButton * button, Application * app);
 void cb_playlistPasteInNewGroup (GtkButton * button, Application * app);
@@ -148,7 +151,8 @@ void app_set_suspend (Application *app, bool suspend) MAEMO_NO_EXPORT;
 void app_set_info_content (Application *app, const char * utf8, bool plaintext) MAEMO_NO_EXPORT;
 void app_set_playing (Application *app, int) MAEMO_NO_EXPORT;
 void app_set_title (const char *title, Application *app) MAEMO_NO_EXPORT;
-gchar *app_file_chooser (Application *app, const char *title, GtkFileChooserAction act);
+gchar *app_file_chooser (Application *app, const char *path, GtkFileChooserAction act);
+void app_store_save_directory (Application *app, gchar *path);
 
 void openFile (Application *app, const gchar *path) MAEMO_NO_EXPORT;
 const char *saveFile (void *ctr, const gchar *path) MAEMO_NO_EXPORT;
