@@ -339,11 +339,11 @@ String Generator::genReadAsk (Control *ctr, Node *n) {
     String desc;
     String type = static_cast<Element*>(n)->getAttribute(StringPool::attr_type);
     String key = static_cast<Element*>(n)->getAttribute ("key");
-    String def;
+    String def = static_cast<Element*>(n)->getAttribute ("default");
     String input;
     if (!key.isEmpty ())
         def = m_control->m_config->readEntry (
-                String (GCONF_KEY_KEYS) + key, "");
+                String (GCONF_KEY_KEYS) + key, def);
     if (type == "file") {
         input = app_file_chooser (m_control->m_app, def,
                 GTK_FILE_CHOOSER_ACTION_OPEN);
@@ -508,12 +508,21 @@ void Generator::begin () {
     if (!unix_process)
         unix_process = new UnixProcess (
                 this, UnixProcess::StdIn | UnixProcess::StdOut);
-    message (MsgInfoString, &process);
+    String info;
+    if (media_info)
+        info = String ("Input data ") +
+            String::number (media_info->rawData ().size () / 1024.0) + "kb | ";
+    info += process;
+    message (MsgInfoString, &info);
     if (unix_process->start (m_control->data_dir, process)) {
         state = state_began;
         write_pos = 0;
         if (media_info && media_info->rawData ().size ())
             unix_process->pollStdIn (true);
+    } else {
+        String err ("Couldn't start process");
+        message (MsgInfoString, &err);
+        deactivate ();
     }
 }
 
@@ -529,11 +538,13 @@ void Generator::deactivate () {
 
 void *Generator::message (KMPlayer::MessageType msg, void *content) {
     if (MsgMediaReady == msg) {
-        String info ("Input data received ");
-        if (media_info)
-            info += String::number (media_info->rawData ().size () >> 8) + "kb";
-        message (MsgInfoString, &info);
-        begin ();
+        if (!media_info->rawData ().size ()) {
+            String err ("No input data received");
+            message (MsgInfoString, &err);
+            deactivate ();
+        } else {
+            begin ();
+        }
     } else {
         return FileDocument::message (msg, content);
     }
@@ -562,7 +573,7 @@ void Generator::readEvent (UnixProcess *) {
             pl->normalize ();
             pl->title = title;
             message (MsgInfoString, NULL);
-            m_control->openDocument (n, n);
+            m_control->openDocument (n, NULL);
         } else {
             String err ("No data received");
             message (MsgInfoString, &err);
@@ -583,6 +594,7 @@ void Generator::writeEvent (UnixProcess *) {
             return;
     }
     unix_process->closeStdIn ();
+    message (MsgInfoString, &process);
 }
 
 void Generator::processExited (UnixProcess *) {
