@@ -285,7 +285,7 @@ KDE_NO_EXPORT void RP::TimingsBase::activate () {
                 if (n->isElementNode () &&
                         static_cast <Element *> (n)->
                             getAttribute ("handle") == a->value ())
-                    target = n;
+                    target = n->self ();
             }
         } else if (a->name () == "start") {
             int dur;
