@@ -41,15 +41,16 @@ KMPLAYER_NO_EXPORT Node *RSS::Channel::childFromTag (const String & tag) {
 }
 
 KMPLAYER_NO_EXPORT void RSS::Channel::closed () {
-    for (NodePtr c = firstChild (); c; c = c->nextSibling ())
+    for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
-            caption = c->innerText ().stripWhiteSpace ();
+            title = c->innerText ().stripWhiteSpace ();
             break;
         }
+    Title::closed ();
 }
 
 KMPLAYER_NO_EXPORT bool RSS::Channel::expose () const {
-    return !caption.isEmpty () || //return false if no caption and only one
+    return !title.isEmpty () || //return false if no caption and only one
         previousSibling () || nextSibling ();
 }
 
@@ -72,10 +73,10 @@ KMPLAYER_NO_EXPORT Node *RSS::Item::childFromTag (const String & tag) {
 
 KMPLAYER_NO_EXPORT void RSS::Item::closed () {
     cached_play_type = play_type_none;
-    for (NodePtr c = firstChild (); c; c = c->nextSibling ()) {
+    for (Node *c = firstChild (); c; c = c->nextSibling ()) {
         switch (c->id) {
             case id_node_title:
-                caption = c->innerText ().stripWhiteSpace ();
+                title = c->innerText ().stripWhiteSpace ();
                 break;
             case id_node_enclosure:
                 enclosure = c;
@@ -88,8 +89,9 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
     }
     if (enclosure && !enclosure->mrl ()->src.isEmpty ()) {
         cached_play_type = play_type_audio;
-        enclosure->caption = caption;
+        enclosure->mrl ()->title = title;
     }
+    Mrl::closed ();
 }
 
 KMPLAYER_NO_EXPORT Mrl * RSS::Item::linkNode () {
@@ -98,20 +100,22 @@ KMPLAYER_NO_EXPORT Mrl * RSS::Item::linkNode () {
     return Mrl::linkNode ();
 }
 
+String RSS::Item::description () const {
+    for (Node *c = firstChild (); c; c = c->nextSibling ())
+        if (c->id == id_node_description)
+            return c->innerText ();
+    return String ();
+}
+
 KMPLAYER_NO_EXPORT void RSS::Item::activate () {
-    for (NodePtr c = firstChild (); c; c = c->nextSibling ())
-        if (c->id == id_node_description) {
-            String s = c->innerText ();
-            document ()->message (MsgInfoString, &s);
-            if (!enclosure && !s.isEmpty ()) {
-                setState (state_activated);
-                begin ();
-                timer = document ()->post (this,
-                        new TimerPosting (5000+s.length()*200));
-                return;
-            }
-            break;
-        }
+    String s = description ();
+    if (!enclosure && !s.isEmpty ()) {
+        setState (state_activated);
+        begin ();
+        timer = document ()->post (this,
+                new TimerPosting (5000+s.length()*200));
+        return;
+    }
     Mrl::activate ();
 }
 
@@ -135,4 +139,5 @@ KDE_NO_EXPORT void *RSS::Item::message (MessageType msg, void *content) {
 
 KDE_NO_EXPORT void RSS::Enclosure::closed () {
     src = getAttribute (StringPool::attr_url);
+    Mrl::closed ();
 }
