@@ -639,7 +639,7 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
     if (ns == Node::state_deactivated &&
             n == playlist_data->document && !back_request) {
         stop ();
-        VIEWAREA(m_app)->setEventFiltering (m_app, false);
+        //VIEWAREA(m_app)->setEventFiltering (m_app, false);
         app_set_playing (m_app, NOT_PLAYING);
     } else if ((ns == Node::state_deactivated || ns == Node::state_finished) &&
             n->mrl () && process ()->mrl () == n->mrl()->linkNode ()) {
@@ -654,12 +654,12 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
                 (ns > Node::state_deferred &&
                  m_process->state() == Process::Paused))
             m_process->pause ();
-        VIEWAREA(m_app)->setEventFiltering (m_app, true);
+        //VIEWAREA(m_app)->setEventFiltering (m_app, true);
         app_set_playing (m_app, ns > Node::state_deferred ? PLAYING : PAUSED);
     } else if (ns == Node::state_activated ||
             (os == Node::state_init && ns == Node::state_deferred)) {
         if (n == playlist_data->document) {
-            VIEWAREA(m_app)->setEventFiltering (m_app, true);
+            //VIEWAREA(m_app)->setEventFiltering (m_app, true);
             app_set_playing (m_app, PLAYING);
         }
         if (n->id == SMIL::id_node_body)
