@@ -727,7 +727,7 @@ void Mrl::begin () {
             media_info = new MediaInfo (this, ActorAgent::AudioVideo);
         if (!media_info->media)
             media_info->create ();
-        if (media_info->media->play ())
+        if (media_info->media && media_info->media->play ())
             setState (state_began);
         else
             deactivate ();
