@@ -116,13 +116,16 @@ public:
 
     T* first () const { return m_first.ptr (); }
     T* last () const { return m_last.ptr (); }
-    void append (typename Item<T>::SharedType c);
-    void insertBefore (typename Item<T>::SharedType c, typename Item<T>::SharedType b);
-    void remove (typename Item<T>::SharedType c);
+    void append (T *c);
+    void insertBefore (T *c, T *b);
+    void remove (T *c);
     void clear ();
     unsigned int length () const;
     T* item (int i) const;
+
 protected:
+    void removeImpl (T *c);
+
     typename Item<T>::SharedType m_first;
     typename Item<T>::WeakType m_last;
 };
@@ -279,6 +282,7 @@ typedef Item<NodeRefList>::SharedType NodeRefListPtr;
 typedef Item<NodeRefList>::WeakType NodeRefListPtrW;
 ITEM_AS_POINTER(KMPlayer::NodeRefList)
 
+template <> void List<NodeRefItem>::remove (NodeRefItem *c);
 template <> void TreeNode<Node>::appendChild (Node *c);
 template <> void TreeNode<Node>::insertBefore (Node *c, Node *b);
 template <> void TreeNode<Node>::removeChild (NodePtr c);
@@ -883,48 +887,56 @@ KMPLAYER_EXPORT Node * fromXMLDocumentTag (NodePtr & d, const String & tag);
 template <class T>
 inline Item<T>::Item () : m_self (static_cast <T*> (this), true) {}
 
-template <class T> inline void List<T>::append(typename Item<T>::SharedType c) {
+template <class T> inline void List<T>::append (T *c) {
     if (!m_first) {
-        m_first = m_last = c;
+        m_first = c->m_self;
+        m_last = c->m_self;
     } else {
-        m_last->m_next = c;
+        m_last->m_next = c->m_self;
         c->m_prev = m_last;
-        m_last = c;
+        m_last = c->m_self;
     }
 }
 
-template <class T> inline void List<T>::insertBefore(typename Item<T>::SharedType c, typename Item<T>::SharedType b) {
+template <class T> inline void List<T>::insertBefore (T *c, T *b) {
     if (!b) {
         append (c);
     } else {
+        c->m_next = b->m_self;
         if (b->m_prev) {
-            b->m_prev->m_next = c;
+            b->m_prev->m_next = c->m_self;
             c->m_prev = b->m_prev;
         } else {
             c->m_prev = 0L;
-            m_first = c;
+            m_first = c->m_self;
         }
-        b->m_prev = c;
-        c->m_next = b;
+        b->m_prev = c->m_self;
     }
 }
 
-template <class T> inline void List<T>::remove(typename Item<T>::SharedType c) {
+template <class T> inline void List<T>::removeImpl (T *c) {
+    typename Item<T>::SharedType s = c->m_self;
     if (c->m_prev) {
         c->m_prev->m_next = c->m_next;
-    } else
+        c->m_prev = 0L;
+    } else {
         m_first = c->m_next;
+    }
     if (c->m_next) {
         c->m_next->m_prev = c->m_prev;
         c->m_next = 0L;
-    } else
+    } else {
         m_last = c->m_prev;
-    c->m_prev = 0L;
+    }
+}
+
+template <class T> inline void List<T>::remove (T *c) {
+    removeImpl (c);
 }
 
 template <class T> inline unsigned int List<T>::length () const {
     unsigned int count = 0;
-    for (typename Item<T>::SharedType t = m_first; t; t = t->nextSibling ())
+    for (T *t = m_first.ptr (); t; t = t->nextSibling ())
         count++;
     return count;
 }
