@@ -33,6 +33,7 @@ namespace KMPlayer {
 
 class Viewer;
 class ProcessNotify;
+class UnixProcess;
 
 /*
  * Base class for all backend processes
@@ -117,7 +118,6 @@ protected:
  */
 class ProcessNotify {
 public:
-    virtual ~ProcessNotify () {}
     virtual void stateChanged (Process * proc, Process::State os, Process::State ns)=0;
     virtual void errorMsg (const String & msg) = 0;
     virtual void setLoading (int perc) = 0;
@@ -126,10 +126,44 @@ public:
     virtual void setAspect (float aspect) = 0;
 };
 
+class UnixProcessListener {
+public:
+    virtual void readEvent (UnixProcess *) = 0;
+    virtual void writeEvent (UnixProcess *) = 0;
+    virtual void processExited (UnixProcess *) = 0;
+};
+
+class UnixProcess {
+public:
+    enum { NoIO = 0, StdIn = 0x01, StdOut = 0x02 };
+
+    UnixProcess (UnixProcessListener *l, int flags);
+
+    bool start (const String &pwd, const String &cmdline);
+    void stop ();
+    bool running () const;
+    void pollStdIn (bool b);
+    void closeStdIn ();
+    void closeStdOut ();
+    int writeStdIn (const char *data, int len);
+    int readStdOut (char *buf, int len);
+
+    void readEvent (GIOChannel *channel);
+    void writeEvent ();
+    void processExited (GPid pid);
+
+    UnixProcessListener *listener;
+    int io_flags;
+    GIOChannel *pin, *pout, *perr;
+    int win, wout, werr;
+    GPid process_id;
+    bool eof;
+};
+
 /*
  * MM backend using MPlayer
  */
-class MPlayer : public Process {
+class MPlayer : public Process, public UnixProcessListener {
 public:
     MPlayer (ProcessNotify * ctrl, bool xv);
     ~MPlayer ();
@@ -145,22 +179,22 @@ public:
     virtual bool contrast (int pos, bool absolute);
     virtual bool brightness (int pos, bool absolute);
     virtual void setVideoWindow (int x, int y, int w, int h);
-    // for callback functions
-    void processExited (GPid pid);
-    void writeEvent ();
-    void readEvent (GIOChannel * src);
+
+    // for UnixProcessListener functions
+    void processExited (UnixProcess *);
+    void writeEvent (UnixProcess *);
+    void readEvent (UnixProcess *);
+
 private:
     bool sendCommand (const String &);
     typedef std::list <String> StringList;
     StringList commands;
     String command_chunk;
-    Rect m_rect;
-    GIOChannel *pin, *pout, *perr;
-    int win, wout, werr;
+    IRect m_rect;
+    UnixProcess unix_process;
     int request_seek;
     char outbuf[512];
     bool request_quit;
-    GPid process_id;
     bool wait_for_pause;
 };
 
@@ -202,8 +236,8 @@ public: //slots:
     void updateVideoSize ();
 private:
     osso_context_t * m_osso_context;
-    Rect m_rect;  // see setVideoWindow (..)
-    Rect m_cur_rect; // last real setting
+    IRect m_rect;  // see setVideoWindow (..)
+    IRect m_cur_rect; // last real setting
     double m_volume;
     const char *current_service;
     const char *dbus_filter;
@@ -251,7 +285,7 @@ private:
     bool processing;
 };
 
-class KMPLAYER_NO_EXPORT NpStream : public AsyncJobInterface {
+class KMPLAYER_NO_EXPORT NpStream : public IOJobListener {
 public:
     enum Reason {
         NoReason = -1,
@@ -264,13 +298,13 @@ public:
     void open ();
     void close ();
 
-    virtual void jobData (Job * job, ByteArray & data);
-    virtual void jobResult (Job * job);
-    virtual void redirected (Job * job, const String & uri);
+    virtual void jobData (IOJob * job, ByteArray & data);
+    virtual void jobResult (IOJob * job);
+    virtual void redirected (IOJob * job, const String & uri);
 
     uint32_t stream;
     URL url;
-    Job *job;
+    IOJob *job;
     uint32_t bytes;
     Reason finish_reason;
 private:
@@ -282,7 +316,7 @@ private:
 /*
  * Download backend
  */
-class Downloader : public Process, public AsyncJobInterface {
+class Downloader : public Process, public IOJobListener {
 public:
     Downloader (ProcessNotify * ctrl, Application *app);
     ~Downloader ();
@@ -293,10 +327,11 @@ public:
     String saved_file;
 
 private:
-    virtual void jobData (Job *job, ByteArray & data);
-    virtual void jobResult (Job *job);
+    virtual void jobData (IOJob *job, ByteArray & data);
+    virtual void jobResult (IOJob *job);
+    virtual void redirected (IOJob * job, const String & uri);
 
-    Job *job;
+    IOJob *job;
     Application *application;
     unsigned long size;
     unsigned long bytes;
