@@ -892,9 +892,12 @@ size_t CurlGetJob::headerLine( void *ptr, size_t size, size_t nmemb, void *strea
             char *p = strchr ((char *)ptr + 5, ' ');
             if (p) {
                 int rc = strtol (p +1, NULL, 10);
-                if (rc >= 400)
+                if (rc >= 400) {
                     self->error_code = rc;
-                else if (rc >= 300)
+                    gchar *buf = g_strndup (p + 1, size * nmemb);
+                    debugLog() << "CurlGetJob err: " << buf << endl;
+                    g_free (buf);
+                }  else if (rc >= 300)
                     self->redirected = true;
             }
         } else if (self->redirected && !strncasecmp ((char *)ptr, "location:", 9)) {
@@ -906,6 +909,9 @@ size_t CurlGetJob::headerLine( void *ptr, size_t size, size_t nmemb, void *strea
         } else if (!strncasecmp ((char *)ptr, "content-type:", 13)) {
             self->content_type = String (
                     (char *)ptr + 13, size * nmemb - 13).stripWhiteSpace ();
+            int pos = self->content_type.indexOf (Char (';'));
+            if (pos > 0)
+                self->content_type = self->content_type.left (pos);
         }
     }
     return size * nmemb;
@@ -938,7 +944,7 @@ void CurlGetJob::init (IOJob *job) {
     if (!multi)
         multi = curl_multi_init ();
     easy = curl_easy_init ();
-    debugLog() << "CurlGetJob::CurlGetJob " << easy << " " << ++job_count << endl;
+    //debugLog() << "CurlGetJob::CurlGetJob " << easy << " " << ++job_count << endl;
     g_tree_insert (easy_list, easy, job);
     //curl_easy_setopt (easy, CURLOPT_VERBOSE, true);
     curl_easy_setopt (easy, CURLOPT_NOPROGRESS, true);
