@@ -44,8 +44,8 @@ public:
     Matrix (Single xoff, Single yoff, float xscale, float yscale);
     void getXY (Single & x, Single & y) const;
     void getWH (Single & w, Single & h) const;
-    void getXYWH (Single & x, Single & y, Single & w, Single & h) const;
-    void invXYWH (Single & x, Single & y, Single & w, Single & h) const;
+    IRect toScreen (const SRect &rect) const;
+    SRect toUser (const IRect &rect) const;
     void transform (const Matrix & matrix);
     void scale (float sx, float sy);
     void translate (Single x, Single y);
@@ -60,7 +60,7 @@ public:
 
     void clear ();
     Surface *createSurface (NodePtr owner, const SRect & rect);
-    IRect toScreen (Single x, Single y, Single w, Single h);
+    IRect toScreen (const SSize &size);
     void resize (const SRect & rect, bool parent_resized=false);
     void repaint ();
     void repaint (const SRect &rect);
@@ -90,6 +90,10 @@ typedef Item<Surface>::SharedType SurfacePtr;
 typedef Item<Surface>::WeakType SurfacePtrW;
 ITEM_AS_POINTER(KMPlayer::Surface)
 
+//template <> void TreeNode<Surface>::appendChild (Surface *c);
+template <> void TreeNode<Surface>::insertBefore (Surface *c, Surface *b);
+template <> void TreeNode<Surface>::removeChild (SurfacePtr c);
+
 } // namespace
 
 #endif
