@@ -1994,6 +1994,31 @@ static int getChildWindowDepth (Display *dpy, Window p, Window c, int depth) {
     return d;
 }
 
+static int tree_x_down;
+static int tree_y_down;
+static int tree_x_root_down;
+static int tree_y_root_down;
+static int tree_x_root_scroll;
+static int tree_y_root_scroll;
+static unsigned tree_time_scroll;
+static unsigned tree_window_down;
+static bool tree_scrolled;
+static const int tree_threshold = 14;
+
+static bool updateScroll (GtkAdjustment *adj, int pix) {
+    if (!adj || !pix)
+        return false;
+    double d = gtk_adjustment_get_value (adj);
+    double pc = (adj->upper - adj->lower) / adj->page_size;
+    d -= pc * pix;
+    if (d < adj->lower)
+        d = adj->lower;
+    if (d > adj->upper - adj->page_size)
+        d = adj->upper - adj->page_size;
+    gtk_adjustment_set_value (adj, d);
+    return true;
+}
+
 static
 GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
     XEvent *event = (XEvent *) xe;
@@ -2007,102 +2032,175 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
         return GDK_FILTER_CONTINUE;
 
     switch (event->xany.type) {
-        case KeyPress:
-        case KeyRelease: {
-            XKeyEvent keyevent = event->xkey;
-            if (a->fullscreen &&
-                    XKeycodeToKeysym (event->xany.display, keyevent.keycode, 0) == XK_F4)
-                return GDK_FILTER_REMOVE; //GDK_FILTER_CONTINUE;
+    case KeyPress:
+    case KeyRelease: {
+        XKeyEvent keyevent = event->xkey;
+        if (a->fullscreen &&
+                XKeycodeToKeysym (event->xany.display, keyevent.keycode, 0) == XK_F4)
+            return GDK_FILTER_REMOVE; //GDK_FILTER_CONTINUE;
+        Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
+        Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
+        int depth = event->xany.window == i
+            ? 0
+            : getChildWindowDepth (event->xany.display, v,
+                    event->xkey.window, 0);
+        if (depth >= 0) {
+            keyevent.window =
+                GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window));
+            XSendEvent (event->xany.display, keyevent.window, true,
+                    KeyPressMask, (XEvent *) &keyevent);
+            return GDK_FILTER_REMOVE;
+        }
+        break;
+    }
+    case MapNotify: {
+        Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
+        if (!event->xmap.override_redirect) {
+            int depth = getChildWindowDepth (event->xany.display,
+                    v, event->xmap.window, 0);
+            if (depth >= 0) {
+                setXSelectInput (event->xany.display,
+                        event->xmap.window,
+                        KeyPressMask|ExposureMask|SubstructureNotifyMask);
+            }
+        }
+        break;
+    }
+    case ConfigureNotify:
+        if (view_area->videoInputWindow ()) {
             Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
             Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
-            int depth = event->xany.window == i
-                ? 0
-                : getChildWindowDepth (event->xany.display, v,
-                        event->xkey.window, 0);
-            if (depth >= 0) {
-                keyevent.window =
-                    GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window));
-                XSendEvent (event->xany.display, keyevent.window, true,
-                        KeyPressMask, (XEvent *) &keyevent);
+            if (event->xconfigure.window == v &&
+                    event->xconfigure.above == i)
+                XRaiseWindow (event->xany.display, i);
+        }
+        break;
+    case ButtonPress: {
+        tree_scrolled = false;
+        if (getChildWindowDepth (event->xany.display,
+                    GDK_DRAWABLE_XID(GDK_DRAWABLE(a->playlist_view->window)),
+                    event->xbutton.window, 0) >= 0) {
+            if (event->xbutton.button == 1) {
+                tree_x_down = event->xbutton.x;
+                tree_y_down = event->xbutton.y;
+                tree_x_root_down = event->xbutton.x_root;
+                tree_y_root_down = event->xbutton.y_root;
+                tree_window_down = event->xbutton.window;
                 return GDK_FILTER_REMOVE;
             }
-            break;
+            return GDK_FILTER_CONTINUE;
         }
-        case MapNotify: {
-            Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
-            if (!event->xmap.override_redirect) {
-                int depth = getChildWindowDepth (event->xany.display,
-                        v, event->xmap.window, 0);
-                if (depth >= 0) {
-                    setXSelectInput (event->xany.display,
-                            event->xmap.window,
-                            KeyPressMask|ExposureMask|SubstructureNotifyMask);
-                }
-            }
-            break;
-        }
-        case ConfigureNotify:
-            if (view_area->videoInputWindow ()) {
-                Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
-                Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
-                if (event->xconfigure.window == v &&
-                        event->xconfigure.above == i)
-                    XRaiseWindow (event->xany.display, i);
-            }
-            break;
-        case ButtonPress: {
-            Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
-            Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
-            Window w = GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window));
-            IRect vr = view_area->videoGeometry ();
-            if (a->fullscreen &&
-                    (event->xany.window == w &&
-                     event->xbutton.x > 720 && event->xbutton.y < 80) ||
-                    (event->xany.window == i &&
-                     event->xbutton.x + vr.x () > 720 &&
-                     event->xbutton.y + vr.y () < 80)) {
-                if (!view_area->controls_timer)
-                    updatePlayTree (a);
-                view_area->controlsVisible (a, true);
-            } else if (event->xany.window == w || event->xany.window == i) {
-                if (event->xbutton.time - down_time < 500 &&
-                        abs (down_x - event->xbutton.x) < 80 &&
-                        abs (down_y - event->xbutton.y) < 80) {
-                    view_area->prepareFullscreenToggle ();
-                    if (a->fullscreen)
-                        app_normal_screen (a);
-                    else
-                        app_full_screen (a);
-                    down_time = 0;
-                    return GDK_FILTER_REMOVE;
-                } else {
-                    down_x = event->xbutton.x;
-                    down_y = event->xbutton.y;
-                    down_time = event->xbutton.time;
-                }
+        tree_window_down = 0;
+        Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
+        Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
+        Window w = GDK_DRAWABLE_XID (GDK_DRAWABLE (view_area->viewWidget ()->window));
+        IRect vr = view_area->videoGeometry ();
+        if (a->fullscreen &&
+                (event->xany.window == w &&
+                 event->xbutton.x > 720 && event->xbutton.y < 80) ||
+                (event->xany.window == i &&
+                 event->xbutton.x + vr.x () > 720 &&
+                 event->xbutton.y + vr.y () < 80)) {
+            if (!view_area->controls_timer)
+                updatePlayTree (a);
+            view_area->controlsVisible (a, true);
+        } else if (event->xany.window == w || event->xany.window == i) {
+            if (event->xbutton.time - down_time < 500 &&
+                    abs (down_x - event->xbutton.x) < 80 &&
+                    abs (down_y - event->xbutton.y) < 80) {
+                view_area->prepareFullscreenToggle ();
+                if (a->fullscreen)
+                    app_normal_screen (a);
+                else
+                    app_full_screen (a);
+                down_time = 0;
+                return GDK_FILTER_REMOVE;
+            } else {
+                down_x = event->xbutton.x;
+                down_y = event->xbutton.y;
+                down_time = event->xbutton.time;
             }
         }
-        // fall through
-        case ButtonRelease:
-            if (event->xany.window == GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()))) {
-                XButtonEvent evt = event->xbutton;
-                int evt_mask = event->xany.type == ButtonRelease
+    }
+    // fall through
+    case ButtonRelease:
+        if (tree_window_down) {
+            GdkFilterReturn ret = GDK_FILTER_REMOVE;
+            if (tree_window_down == event->xbutton.window &&
+                    !tree_scrolled &&
+                    abs (event->xbutton.x - tree_x_down) < tree_threshold &&
+                    abs (event->xbutton.y - tree_y_down) < tree_threshold) {
+                GdkEventButton evt;
+                evt.type = GDK_BUTTON_PRESS;
+                evt.window = gdk_window_lookup_for_display (
+                        gdk_x11_lookup_xdisplay (event->xany.display),
+                        event->xany.window);
+                evt.send_event = false;
+                evt.x = tree_x_down;
+                evt.y = tree_y_down;
+                evt.x_root = tree_x_root_down;
+                evt.y_root = tree_y_root_down;
+                evt.axes = NULL;
+                evt.state = 0;
+                evt.button = 1;
+                evt.time = event->xbutton.time;
+                evt.device = gdk_device_get_core_pointer ();
+                gtk_main_do_event ((GdkEvent *) &evt);
+                ret = GDK_FILTER_CONTINUE;
+            }
+            tree_window_down = 0;
+            tree_scrolled = false;
+            return ret;
+        }
+        if (event->xany.window == GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()))) {
+            XButtonEvent evt = event->xbutton;
+            int evt_mask = event->xany.type == ButtonRelease
                 ? ButtonReleaseMask : ButtonPressMask;
-                if (findWindowAt (event->xany.display,
-                            GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow())),
-                            evt_mask,
-                            &evt.x, &evt.y, &evt.window, &evt.subwindow)) {
-                    XSendEvent (event->xany.display, evt.window, False,
-                            evt_mask, (XEvent *) &evt);
+            if (findWindowAt (event->xany.display,
+                        GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow())),
+                        evt_mask,
+                        &evt.x, &evt.y, &evt.window, &evt.subwindow)) {
+                XSendEvent (event->xany.display, evt.window, False,
+                        evt_mask, (XEvent *) &evt);
+                XFlush (event->xany.display);
+                if (event->xany.type == ButtonRelease) {
+                    XSetInputFocus (event->xany.display, evt.window,
+                            RevertToParent, CurrentTime);
                     XFlush (event->xany.display);
-                    if (event->xany.type == ButtonRelease) {
-                        XSetInputFocus (event->xany.display, evt.window,
-                                RevertToParent, CurrentTime);
-                        XFlush (event->xany.display);
+                }
+                return GDK_FILTER_REMOVE;
+            }
+        }
+        break;
+    case MotionNotify:
+        if (tree_window_down) {
+            if (tree_scrolled ||
+                    abs (event->xmotion.x_root - tree_x_root_down) >
+                        tree_threshold ||
+                    abs (event->xmotion.y_root - tree_y_root_down) >
+                        tree_threshold) {
+                if (!tree_scrolled) {
+                    tree_scrolled = true;
+                    tree_time_scroll = 0;
+                    tree_x_root_scroll = tree_x_root_down;
+                    tree_y_root_scroll = tree_y_root_down;
+                }
+                if (event->xmotion.time - tree_time_scroll > 80) {
+                    bool scrolled = updateScroll (gtk_tree_view_get_vadjustment(
+                                GTK_TREE_VIEW (a->playlist_view)),
+                            event->xmotion.y_root - tree_y_root_scroll);
+                    scrolled |= updateScroll (gtk_tree_view_get_hadjustment(
+                                GTK_TREE_VIEW (a->playlist_view)),
+                            event->xmotion.x_root - tree_x_root_scroll);
+                    if (scrolled) {
+                        tree_x_root_scroll = event->xmotion.x_root;
+                        tree_y_root_scroll = event->xmotion.y_root;
+                        tree_time_scroll = event->xmotion.time;
                     }
-                    return GDK_FILTER_REMOVE;
                 }
             }
+            return GDK_FILTER_REMOVE;
+        }
     }
     return GDK_FILTER_CONTINUE;
 }
@@ -2247,6 +2345,7 @@ KDE_NO_EXPORT void ViewArea::setOutputWidget (Application *app, GtkWidget * w) {
         setAudioVideoGeometry (IRect (-100, -100, 50, 50), 0L);
 
         debugLog() << "video window "  << (int)GDK_DRAWABLE_XID (GDK_DRAWABLE (video)) << " " << endl;
+        setEventFiltering (app, true);
 
     } else {
         gdk_window_reparent (video, widget->window, m_av_geometry.x(), m_av_geometry.y());
